diff --git a/var/spack/repos/builtin/packages/encodings/package.py b/var/spack/repos/builtin/packages/encodings/package.py
deleted file mode 100644
index c075978069d70a2aaa066f27f209d9eac91a2dd1..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/encodings/package.py
+++ /dev/null
@@ -1,31 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class Encodings(Package):
-    """X.org encodings font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/encodings"
-    url      = "https://www.x.org/archive/individual/font/encodings-1.0.4.tar.gz"
-
-    version('1.0.4', '1a631784ce204d667abcc329b851670c')
-
-    depends_on('font-util')
-
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-adobe-100dpi/package.py b/var/spack/repos/builtin/packages/font-adobe-100dpi/package.py
deleted file mode 100644
index ab422f91390ce2b3823b522535a99157be21254e..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-adobe-100dpi/package.py
+++ /dev/null
@@ -1,31 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontAdobe100dpi(AutotoolsPackage):
-    """X.org adobe-100dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/adobe-100dpi"
-    url      = "https://www.x.org/archive/individual/font/font-adobe-100dpi-1.0.3.tar.gz"
-
-    version('1.0.3', 'ba61e7953f4f5cec5a8e69c262bbc7f9')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-adobe-75dpi/package.py b/var/spack/repos/builtin/packages/font-adobe-75dpi/package.py
deleted file mode 100644
index ed87f75e53379a6e7f188f7260761030085bd87b..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-adobe-75dpi/package.py
+++ /dev/null
@@ -1,31 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontAdobe75dpi(AutotoolsPackage):
-    """X.org adobe-75dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/adobe-75dpi"
-    url      = "https://www.x.org/archive/individual/font/font-adobe-75dpi-1.0.3.tar.gz"
-
-    version('1.0.3', '7a414bb661949cec938938fd678cf649')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-adobe-utopia-100dpi/package.py b/var/spack/repos/builtin/packages/font-adobe-utopia-100dpi/package.py
deleted file mode 100644
index 042be2c23698f26ad32d732d1f14a8d15677bbeb..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-adobe-utopia-100dpi/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontAdobeUtopia100dpi(Package):
-    """X.org adobe-utopia-100dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/adobe-utopia-100dpi"
-    url      = "https://www.x.org/archive/individual/font/font-adobe-utopia-100dpi-1.0.4.tar.gz"
-
-    version('1.0.4', '128416eccd59b850f77a9b803681da3c')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-adobe-utopia-75dpi/package.py b/var/spack/repos/builtin/packages/font-adobe-utopia-75dpi/package.py
deleted file mode 100644
index 381427b65fd2dd42afd182c96262bf70818be255..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-adobe-utopia-75dpi/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontAdobeUtopia75dpi(Package):
-    """X.org adobe-utopia-75dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/adobe-utopia-75dpi"
-    url      = "https://www.x.org/archive/individual/font/font-adobe-utopia-75dpi-1.0.4.tar.gz"
-
-    version('1.0.4', '74c73a5b73c6c3224b299f1fc033e508')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-adobe-utopia-type1/package.py b/var/spack/repos/builtin/packages/font-adobe-utopia-type1/package.py
deleted file mode 100644
index f3241a299592adf15f67ffc227e8d5d46032e210..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-adobe-utopia-type1/package.py
+++ /dev/null
@@ -1,32 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontAdobeUtopiaType1(Package):
-    """X.org adobe-utopia-type1 font."""
-
-    homepage = "https://cgit.freedesktop.org/xorg/font/adobe-utopia-type1"
-    url      = "https://www.x.org/archive/individual/font/font-adobe-utopia-type1-1.0.4.tar.gz"
-
-    version('1.0.4', 'b0676c3495acabad519ee98a94163904')
-
-    depends_on('font-util', type='build')
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-alias/package.py b/var/spack/repos/builtin/packages/font-alias/package.py
deleted file mode 100644
index dadf8d9ea1d256acc37c52d89d42fbbe5ed7dd11..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-alias/package.py
+++ /dev/null
@@ -1,30 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontAlias(Package):
-    """X.org alias font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/alias"
-    url      = "https://www.x.org/archive/individual/font/font-alias-1.0.3.tar.gz"
-
-    version('1.0.3', '535138efe0a95f5fe521be6a6b9c4888')
-
-    depends_on('font-util')
-
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-arabic-misc/package.py b/var/spack/repos/builtin/packages/font-arabic-misc/package.py
deleted file mode 100644
index d3a9567ddc9e257cce16550ae9ed8dbdc1909356..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-arabic-misc/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontArabicMisc(Package):
-    """X.org arabic-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/arabic-misc"
-    url      = "https://www.x.org/archive/individual/font/font-arabic-misc-1.0.3.tar.gz"
-
-    version('1.0.3', '918457df65ef93f09969c6ab01071789')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bh-100dpi/package.py b/var/spack/repos/builtin/packages/font-bh-100dpi/package.py
deleted file mode 100644
index 8dd20e0f84decaca7558a4fa2687e13830984828..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bh-100dpi/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBh100dpi(Package):
-    """X.org bh-100dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bh-100dpi"
-    url      = "https://www.x.org/archive/individual/font/font-bh-100dpi-1.0.3.tar.gz"
-
-    version('1.0.3', '09e63a5608000531179e1ab068a35878')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bh-75dpi/package.py b/var/spack/repos/builtin/packages/font-bh-75dpi/package.py
deleted file mode 100644
index c3adf9a1b9be2fc3015630f4f8bc059029c08614..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bh-75dpi/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBh75dpi(Package):
-    """X.org bh-75dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bh-75dpi"
-    url      = "https://www.x.org/archive/individual/font/font-bh-75dpi-1.0.3.tar.gz"
-
-    version('1.0.3', '88fec4ebc4a265684bff3abdd066f14f')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bh-lucidatypewriter-100dpi/package.py b/var/spack/repos/builtin/packages/font-bh-lucidatypewriter-100dpi/package.py
deleted file mode 100644
index 21c1c9f3daf3a13ed336fddefe2450d844841377..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bh-lucidatypewriter-100dpi/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBhLucidatypewriter100dpi(Package):
-    """X.org bh-lucidatypewriter-100dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bh-lucidatypewriter-100dpi"
-    url      = "https://www.x.org/archive/individual/font/font-bh-lucidatypewriter-100dpi-1.0.3.tar.gz"
-
-    version('1.0.3', '5f716f54e497fb4ec1bb3a5d650ac6f7')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bh-lucidatypewriter-75dpi/package.py b/var/spack/repos/builtin/packages/font-bh-lucidatypewriter-75dpi/package.py
deleted file mode 100644
index ccfd1d9a98123f12fe6aeadbb3c22e17bea96d05..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bh-lucidatypewriter-75dpi/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBhLucidatypewriter75dpi(Package):
-    """X.org bh-lucidatypewriter-75dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bh-lucidatypewriter-75dpi"
-    url      = "https://www.x.org/archive/individual/font/font-bh-lucidatypewriter-75dpi-1.0.3.tar.gz"
-
-    version('1.0.3', 'cab8a44ae329aab7141c7adeef0daf5a')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bh-ttf/package.py b/var/spack/repos/builtin/packages/font-bh-ttf/package.py
deleted file mode 100644
index c0bb3609a62de104a5901208039e3382feed0410..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bh-ttf/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBhTtf(Package):
-    """X.org bh-ttf font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bh-ttf"
-    url      = "https://www.x.org/archive/individual/font/font-bh-ttf-1.0.3.tar.gz"
-
-    version('1.0.3', '4ce741ec4edaa11cd38988d355a7578b')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bh-type1/package.py b/var/spack/repos/builtin/packages/font-bh-type1/package.py
deleted file mode 100644
index 5bb02fcf42ff50361bda2d7f70dc8bd3dd0a28f9..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bh-type1/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBhType1(Package):
-    """X.org bh-type1 font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bh-type1"
-    url      = "https://www.x.org/archive/individual/font/font-bh-type1-1.0.3.tar.gz"
-
-    version('1.0.3', '62d4e8f782a6a0658784072a5df5ac98')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bitstream-100dpi/package.py b/var/spack/repos/builtin/packages/font-bitstream-100dpi/package.py
deleted file mode 100644
index 681b920f8a957556b9be85dafc183e1d267e35c5..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bitstream-100dpi/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBitstream100dpi(Package):
-    """X.org bitstream-100dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bitstream-100dpi"
-    url      = "https://www.x.org/archive/individual/font/font-bitstream-100dpi-1.0.3.tar.gz"
-
-    version('1.0.3', 'c27bf37e9b8039f93bd90b8131ed37ad')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bitstream-75dpi/package.py b/var/spack/repos/builtin/packages/font-bitstream-75dpi/package.py
deleted file mode 100644
index 9141fb6ead09df8cfc3500121ed04b05c33742b4..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bitstream-75dpi/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBitstream75dpi(Package):
-    """X.org bitstream-75dpi font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bitstream-75dpi"
-    url      = "https://www.x.org/archive/individual/font/font-bitstream-75dpi-1.0.3.tar.gz"
-
-    version('1.0.3', '4ff6c5d6aebe69371e27b09ad8313d25')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bitstream-speedo/package.py b/var/spack/repos/builtin/packages/font-bitstream-speedo/package.py
deleted file mode 100644
index fea028a474f2db13ef37b82b132a88bf4e48d360..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bitstream-speedo/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBitstreamSpeedo(Package):
-    """X.org bitstream-speedo font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bitstream-speedo"
-    url      = "https://www.x.org/archive/individual/font/font-bitstream-speedo-1.0.2.tar.gz"
-
-    version('1.0.2', 'f0a777b351cf5adefefcf4823e0c1c01')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-bitstream-type1/package.py b/var/spack/repos/builtin/packages/font-bitstream-type1/package.py
deleted file mode 100644
index 85386b53dd0fe9050d819f16c5a9e85399729027..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-bitstream-type1/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontBitstreamType1(Package):
-    """X.org bitstream-type1 font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/bitstream-type1"
-    url      = "https://www.x.org/archive/individual/font/font-bitstream-type1-1.0.3.tar.gz"
-
-    version('1.0.3', 'ff91738c4d3646d7999e00aa9923f2a0')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-cronyx-cyrillic/package.py b/var/spack/repos/builtin/packages/font-cronyx-cyrillic/package.py
deleted file mode 100644
index 848b1a43e516cb2d9bada506ec0f403f24bc1add..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-cronyx-cyrillic/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontCronyxCyrillic(Package):
-    """X.org cronyx-cyrillic font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/cronyx-cyrillic"
-    url      = "https://www.x.org/archive/individual/font/font-cronyx-cyrillic-1.0.3.tar.gz"
-
-    version('1.0.3', '3119ba1bc7f775c162c96e17a912fe30')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-cursor-misc/package.py b/var/spack/repos/builtin/packages/font-cursor-misc/package.py
deleted file mode 100644
index 54966180eb5a9d8f2bfe90955bfa689d5d678276..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-cursor-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontCursorMisc(Package):
-    """X.org cursor-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/cursor-misc"
-    url      = "https://www.x.org/archive/individual/font/font-cursor-misc-1.0.3.tar.gz"
-
-    version('1.0.3', 'a0bf70c7e498f1cd8e3fdf6154f2bb00')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-daewoo-misc/package.py b/var/spack/repos/builtin/packages/font-daewoo-misc/package.py
deleted file mode 100644
index fc0684d770ca14520ba8ebe77d7d370ca4944f5d..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-daewoo-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontDaewooMisc(Package):
-    """X.org daewoo-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/daewoo-misc"
-    url      = "https://www.x.org/archive/individual/font/font-daewoo-misc-1.0.3.tar.gz"
-
-    version('1.0.3', '71a7e2796f045c9d217a19c4e6c25bc1')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-dec-misc/package.py b/var/spack/repos/builtin/packages/font-dec-misc/package.py
deleted file mode 100644
index ef3d58d3e9ee9557e25a4f90d9d0e4838883a167..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-dec-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontDecMisc(Package):
-    """X.org dec-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/dec-misc"
-    url      = "https://www.x.org/archive/individual/font/font-dec-misc-1.0.3.tar.gz"
-
-    version('1.0.3', '5a9242f6b60ecf2b8c5b158322ca2a40')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-ibm-type1/package.py b/var/spack/repos/builtin/packages/font-ibm-type1/package.py
deleted file mode 100644
index 0407d66a9485511ca61674bd20b8ecc43ea8cf4f..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-ibm-type1/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontIbmType1(Package):
-    """X.org ibm-type1 font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/ibm-type1"
-    url      = "https://www.x.org/archive/individual/font/font-ibm-type1-1.0.3.tar.gz"
-
-    version('1.0.3', '2806116e4adcb89d3d5ff5faf65e57c1')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-isas-misc/package.py b/var/spack/repos/builtin/packages/font-isas-misc/package.py
deleted file mode 100644
index 42ca2b5c530c3ea294280a4bc23cd0fd020ad918..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-isas-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontIsasMisc(Package):
-    """X.org isas-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/isas-misc"
-    url      = "https://www.x.org/archive/individual/font/font-isas-misc-1.0.3.tar.gz"
-
-    version('1.0.3', 'ecc3b6fbe8f5721ddf5c7fc66f73e76f')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-jis-misc/package.py b/var/spack/repos/builtin/packages/font-jis-misc/package.py
deleted file mode 100644
index c6fd59499cb0c1085f86998c988f866d8c953d90..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-jis-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontJisMisc(Package):
-    """X.org jis-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/jis-misc"
-    url      = "https://www.x.org/archive/individual/font/font-jis-misc-1.0.3.tar.gz"
-
-    version('1.0.3', 'c48ee5749ae25075d2c7a6111c195e7b')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-micro-misc/package.py b/var/spack/repos/builtin/packages/font-micro-misc/package.py
deleted file mode 100644
index ad2f27b48232b3910c60d895045f5b77eaaa5812..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-micro-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontMicroMisc(Package):
-    """X.org micro-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/micro-misc"
-    url      = "https://www.x.org/archive/individual/font/font-micro-misc-1.0.3.tar.gz"
-
-    version('1.0.3', '4de3f0ce500aef85f198c52ace5e66ac')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-misc-cyrillic/package.py b/var/spack/repos/builtin/packages/font-misc-cyrillic/package.py
deleted file mode 100644
index 63200b86b20a14a73b0af25923498f67558dc194..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-misc-cyrillic/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontMiscCyrillic(Package):
-    """X.org misc-cyrillic font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/misc-cyrillic"
-    url      = "https://www.x.org/archive/individual/font/font-misc-cyrillic-1.0.3.tar.gz"
-
-    version('1.0.3', 'e7b13da5325f62dd3f630beade6d2656')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-misc-ethiopic/package.py b/var/spack/repos/builtin/packages/font-misc-ethiopic/package.py
deleted file mode 100644
index 5feea4fbe72a1f9f2c5f62143ebfff080ecae562..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-misc-ethiopic/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontMiscEthiopic(Package):
-    """X.org misc-ethiopic font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/misc-ethiopic"
-    url      = "https://www.x.org/archive/individual/font/font-misc-ethiopic-1.0.3.tar.gz"
-
-    version('1.0.3', '02ddea9338d9d36804ad38f3daadb55a')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-misc-meltho/package.py b/var/spack/repos/builtin/packages/font-misc-meltho/package.py
deleted file mode 100644
index e13252d858842d7c0edcedcbc348364d5ba5dad1..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-misc-meltho/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontMiscMeltho(Package):
-    """X.org misc-meltho font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/misc-meltho"
-    url      = "https://www.x.org/archive/individual/font/font-misc-meltho-1.0.3.tar.gz"
-
-    version('1.0.3', '8380696483478449c39b04612f20eea8')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-misc-misc/package.py b/var/spack/repos/builtin/packages/font-misc-misc/package.py
deleted file mode 100644
index 4c0bb196cd75d77841531b33d79800de5ee253d4..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-misc-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontMiscMisc(Package):
-    """X.org misc-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/misc-misc"
-    url      = "https://www.x.org/archive/individual/font/font-misc-misc-1.1.2.tar.gz"
-
-    version('1.1.2', '23a79b92275375315129b440206c85b9')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-mutt-misc/package.py b/var/spack/repos/builtin/packages/font-mutt-misc/package.py
deleted file mode 100644
index f3db4a3381b497d40e29b98cf93b6788920558b0..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-mutt-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontMuttMisc(Package):
-    """X.org mutt-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/mutt-misc"
-    url      = "https://www.x.org/archive/individual/font/font-mutt-misc-1.0.3.tar.gz"
-
-    version('1.0.3', '6c2de53ba514f720e02af48eef28ff32')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-schumacher-misc/package.py b/var/spack/repos/builtin/packages/font-schumacher-misc/package.py
deleted file mode 100644
index b5f30d9d4ce2a100cf9e542c9e742c84fa39c764..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-schumacher-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontSchumacherMisc(Package):
-    """X.org schumacher-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/schumacher-misc"
-    url      = "https://www.x.org/archive/individual/font/font-schumacher-misc-1.1.2.tar.gz"
-
-    version('1.1.2', '1f3386a0a690ba8117fc05b501f9f91b')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-screen-cyrillic/package.py b/var/spack/repos/builtin/packages/font-screen-cyrillic/package.py
deleted file mode 100644
index edda24a416564b21758f700e497759c8f4cc5b0d..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-screen-cyrillic/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontScreenCyrillic(Package):
-    """X.org screen-cyrillic font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/screen-cyrillic"
-    url      = "https://www.x.org/archive/individual/font/font-screen-cyrillic-1.0.4.tar.gz"
-
-    version('1.0.4', '4cadaf2ba4c4d0f4cb9b4e7b8f0a3019')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-sony-misc/package.py b/var/spack/repos/builtin/packages/font-sony-misc/package.py
deleted file mode 100644
index fd22496fab0258ba54e3d9b3545bbcd504b1d12c..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-sony-misc/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontSonyMisc(Package):
-    """X.org sony-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/sony-misc"
-    url      = "https://www.x.org/archive/individual/font/font-sony-misc-1.0.3.tar.gz"
-
-    version('1.0.3', '4026cb88e2253efc0b8376003780ccb6')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-sun-misc/package.py b/var/spack/repos/builtin/packages/font-sun-misc/package.py
deleted file mode 100644
index 158688d083f1cf9822bb5becf2db68c92df46ec0..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-sun-misc/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontSunMisc(Package):
-    """X.org sun-misc font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/sun-misc"
-    url      = "https://www.x.org/archive/individual/font/font-sun-misc-1.0.3.tar.gz"
-
-    version('1.0.3', '87ce97ce0582e76bc4064a4d4d10db09')
-
-    depends_on('font-util')
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-winitzki-cyrillic/package.py b/var/spack/repos/builtin/packages/font-winitzki-cyrillic/package.py
deleted file mode 100644
index c5e08067c966ce14a5fe90d400a0c7f099b0df3b..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-winitzki-cyrillic/package.py
+++ /dev/null
@@ -1,34 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontWinitzkiCyrillic(Package):
-    """X.org winitzki-cyrillic font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/winitzki-cyrillic"
-    url      = "https://www.x.org/archive/individual/font/font-winitzki-cyrillic-1.0.3.tar.gz"
-
-    version('1.0.3', '777c667b080b33793528d5abf3247a48')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('bdftopcf', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make()
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-xfree86-type1/package.py b/var/spack/repos/builtin/packages/font-xfree86-type1/package.py
deleted file mode 100644
index 40ef43aa42419df7e1a571542ca9bc2cf8df2d05..0000000000000000000000000000000000000000
--- a/var/spack/repos/builtin/packages/font-xfree86-type1/package.py
+++ /dev/null
@@ -1,33 +0,0 @@
-# Copyright 2013-2019 Lawrence Livermore National Security, LLC and other
-# Spack Project Developers. See the top-level COPYRIGHT file for details.
-#
-# SPDX-License-Identifier: (Apache-2.0 OR MIT)
-
-from spack import *
-
-
-class FontXfree86Type1(Package):
-    """X.org xfree86-type1 font."""
-
-    homepage = "http://cgit.freedesktop.org/xorg/font/xfree86-type1"
-    url      = "https://www.x.org/archive/individual/font/font-xfree86-type1-1.0.4.tar.gz"
-
-    version('1.0.4', '89c33c5176cd580de6636ad50ce7777b')
-
-    depends_on('font-util')
-
-    depends_on('fontconfig', type='build')
-    depends_on('mkfontdir', type='build')
-    depends_on('mkfontscale', type='build')
-    depends_on('pkgconfig', type='build')
-    depends_on('util-macros', type='build')
-
-    def install(self, spec, prefix):
-        configure('--prefix={0}'.format(prefix))
-
-        make('install')
-
-        # `make install` copies the files to the font-util installation.
-        # Create a fake directory to convince Spack that we actually
-        # installed something.
-        mkdir(prefix.lib)
diff --git a/var/spack/repos/builtin/packages/font-util/package.py b/var/spack/repos/builtin/packages/font-util/package.py
index 400c7c0f330782c55c04082e2c00385cd5827236..2024d02ae2bb69be6585307219b93811385f41d0 100644
--- a/var/spack/repos/builtin/packages/font-util/package.py
+++ b/var/spack/repos/builtin/packages/font-util/package.py
@@ -7,12 +7,98 @@
 
 
 class FontUtil(AutotoolsPackage):
     """X.Org font package creation/installation utilities."""
 
     homepage = "http://cgit.freedesktop.org/xorg/font/util"
     url      = "https://www.x.org/archive/individual/font/font-util-1.3.1.tar.gz"
-
     version('1.3.1', 'd153a9af216e4498fa171faea2c82514')
 
     depends_on('pkgconfig', type='build')
     depends_on('util-macros', type='build')
+
+    depends_on('bdftopcf', type='build')
+    depends_on('mkfontscale', type='build')
+
+    font_baseurl = 'https://www.x.org/archive/individual/font/'
+    fonts = []
+    # name, version, md5
+    fonts_resource = [
+        ['encodings', '1.0.4', '1a631784ce204d667abcc329b851670c'],
+        ['font-alias', '1.0.3', '535138efe0a95f5fe521be6a6b9c4888'],
+        ['font-adobe-100dpi', '1.0.3', 'ba61e7953f4f5cec5a8e69c262bbc7f9'],
+        ['font-adobe-75dpi', '1.0.3', '7a414bb661949cec938938fd678cf649'],
+        ['font-adobe-utopia-100dpi', '1.0.4',
+         '128416eccd59b850f77a9b803681da3c'],
+        ['font-adobe-utopia-75dpi', '1.0.4',
+         '74c73a5b73c6c3224b299f1fc033e508'],
+        ['font-adobe-utopia-type1', '1.0.4',
+         'b0676c3495acabad519ee98a94163904'],
+        ['font-arabic-misc', '1.0.3', '918457df65ef93f09969c6ab01071789'],
+        ['font-bh-100dpi', '1.0.3', '09e63a5608000531179e1ab068a35878'],
+        ['font-bh-75dpi', '1.0.3', '88fec4ebc4a265684bff3abdd066f14f'],
+        ['font-bh-ttf', '1.0.3', '4ce741ec4edaa11cd38988d355a7578b'],
+        ['font-bh-type1', '1.0.3', '62d4e8f782a6a0658784072a5df5ac98'],
+        ['font-lucidatypewriter-100dpi', '1.0.3',
+         '5f716f54e497fb4ec1bb3a5d650ac6f7'],
+        ['font-lucidatypewriter-75dpi', '1.0.3',
+         'cab8a44ae329aab7141c7adeef0daf5a'],
+        ['font-bitstream-100dpi', '1.0.3', 'c27bf37e9b8039f93bd90b8131ed37ad'],
+        ['font-bitstream-75dpi', '1.0.3', '4ff6c5d6aebe69371e27b09ad8313d25'],
+        ['font-bitstream-speedo', '1.0.2', 'f0a777b351cf5adefefcf4823e0c1c01'],
+        ['font-bitstream-type1', '1.0.3', 'ff91738c4d3646d7999e00aa9923f2a0'],
+        ['font-cronyx-cyrillic', '1.0.3', '3119ba1bc7f775c162c96e17a912fe30'],
+        ['font-cursor-misc', '1.0.3', 'a0bf70c7e498f1cd8e3fdf6154f2bb00'],
+        ['font-daewoo-misc', '1.0.3', '71a7e2796f045c9d217a19c4e6c25bc1'],
+        ['font-dec-misc', '1.0.3', '5a9242f6b60ecf2b8c5b158322ca2a40'],
+        ['font-ibm-type1', '1.0.3', '2806116e4adcb89d3d5ff5faf65e57c1'],
+        ['font-isas-misc', '1.0.3', 'ecc3b6fbe8f5721ddf5c7fc66f73e76f'],
+        ['font-jis-misc', '1.0.3', 'c48ee5749ae25075d2c7a6111c195e7b'],
+        ['font-micro-misc', '1.0.3', '4de3f0ce500aef85f198c52ace5e66ac'],
+        ['font-misc-cyrillic', '1.0.3', 'e7b13da5325f62dd3f630beade6d2656'],
+        ['font-misc-ethiopic', '1.0.3', '02ddea9338d9d36804ad38f3daadb55a'],
+        ['font-misc-meltho', '1.0.3', '8380696483478449c39b04612f20eea8'],
+        ['font-misc-misc', '1.1.2', '23a79b92275375315129b440206c85b9'],
+        ['font-mutt-misc', '1.0.3', '6c2de53ba514f720e02af48eef28ff32'],
+        ['font-schumacher-misc', '1.1.2', '1f3386a0a690ba8117fc05b501f9f91b'],
+        ['font-screen-cyrillic', '1.0.4', '4cadaf2ba4c4d0f4cb9b4e7b8f0a3019'],
+        ['font-sun-misc', '1.0.3', '87ce97ce0582e76bc4064a4d4d10db09'],
+        ['font-winitzki-cyrillic', '1.0.3',
+         '777c667b080b33793528d5abf3247a48'],
+        ['font-xfree86-type1', '1.0.4', '89c33c5176cd580de6636ad50ce7777b'],
+    ]
+    for f_r in fonts_resource:
+        f = f_r[0]
+        resource(name=f, url=font_baseurl + f + '-' + f_r[1] + '.tar.gz',
+             md5=f_r[2], destination=f, when='fonts=' + f)
+        fonts.append(f)
+
+    variant(
+       'fonts',
+       description='Installs fonts',
+       values=fonts,
+       default=','.join(fonts),
+       multi=True
+    )
+
+    def setup_environment(self, spack_env, run_env):
+        spack_env.prepend_path('PATH', self.prefix.bin)
+        spack_env.prepend_path('PKG_CONFIG_PATH',
+                               join_path(self.prefix.lib, 'pkgconfig'))
+
+    @run_after('install')
+    def font_install(self):
+        autoconf_args = ['-ifv']
+        p = join_path(self.spec['util-macros'].prefix, 'share', 'aclocal')
+        autoconf_args.append('--include={0}'.format(p))
+        p = join_path(self.spec.prefix, 'share', 'aclocal')
+        autoconf_args.append('--include={0}'.format(p))
+        fonts = self.spec.variants['fonts'].value
+        autoreconf = which('autoreconf')
+
+        for font in fonts:
+            fontroot = find(font, '*', recursive=False)
+            with working_dir(join_path(font, fontroot[0])):
+                autoreconf(*autoconf_args)
+                configure = Executable("./configure")
+                configure('--prefix={0}'.format(self.prefix))
+                make('install')
@@ -7,12 +7,98 @@
 
 class FontUtil(AutotoolsPackage):
-    """X.Org font package creation/installation utilities."""
+    """X.Org font package creation/installation utilities and fonts."""
 
     homepage = "http://cgit.freedesktop.org/xorg/font/util"